package com.rizzoweb.alarm;

import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Iterator;

public class AlarmTest {

	public static void main(String[] args) throws Exception {

		AlarmManager mgr = new AlarmManager();

		long current = System.currentTimeMillis();
		System.out.println("Current date is " + new Date(current));

		AlarmListener listener = new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("\u0007Alarm : " + schedule);
		  }
		};

		// Date alarm
		mgr.addAlarm(new Date(current + (60 * 1000)), listener);
		mgr.addAlarm(new Date(current + (30 * 1000)), listener);
		mgr.addAlarm(new Date(current + (40 * 1000)), listener);
		mgr.addAlarm(new Date(current + (20 * 1000)), listener);
		mgr.addAlarm(new Date(current + (10 * 1000)), listener);
		mgr.addAlarm(new Date(current + (50 * 1000)), listener);

		mgr.addAlarm(new Date(System.currentTimeMillis() + 300000),
					 new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("5 minutes later");
		  }
		});

		Calendar cal = Calendar.getInstance();
		cal.add(Calendar.WEEK_OF_YEAR, 1);
		mgr.addAlarm(cal.getTime(), new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("\u0007One week later");
		  }
		});


		// Elapsed-time alarm
		mgr.addAlarm(1, true, new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("dring ! (" + new Date() + ")");
		  }
		});


		// Cron-like alarm (minute, hour, day of month, month, day of week, year)
		mgr.addAlarm(-1, -1, -1, -1, -1, -1, new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("Every minute (" + new Date() + ")");
		  }
		});

		mgr.addAlarm(5, -1, -1, -1, -1, -1, new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("Every hour at 5' (" + new Date() + ")");
		  }
		});

		mgr.addAlarm(00, 12, -1, -1, -1, -1, new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("Lunch time (" + new Date() + ")");
		  }
		});

		mgr.addAlarm(24, 15, 11, Calendar.AUGUST, -1, -1, new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("Valerie's birthday");
		  }
		});

		mgr.addAlarm(30, 9, 1, -1, -1, -1, new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("On the first of every month at 9:30");
		  }
		});

		mgr.addAlarm(00, 18, -1, -1, Calendar.FRIDAY, -1, new AlarmListener() {
		  public void handleAlarm(AlarmSchedule schedule) {
			System.out.println("On every Friday at 18:00");
		  }
		});

		try {
			mgr.addAlarm(0, 0, 1, Calendar.JANUARY, -1, 2001,  new AlarmListener() {
			  public void handleAlarm(AlarmSchedule schedule) {
				System.out.println("Does it work ?");
			  }
			});
		} catch (PastDateException ex) {
			System.out.println("Got PastDateException");
		}

		System.out.println("Here are the registered alarms: ");
		System.out.println("----------------------------");
		List list = mgr.getAllAlarms();
		for(Iterator it = list.iterator(); it.hasNext();) {
		  System.out.println("- " + it.next());
		}
		System.out.println("----------------------------");
	  }
}
